@@ -1,8 +1,8 @@
 import mimetypes
-mimetypes.add_type("image/svg+xml", ".svg")
+mimetypes.add_type('image/svg+xml', '.svg')
 
 from zope.i18nmessageid import MessageFactory as mf
-MessageFactory = mf("euphorie")
+MessageFactory = mf('euphorie')
 del mf
 
 #: Version number for terms and conditions. Updating this version will
@@ -23,8 +23,12 @@ def initialize(context):
                                         authentication.addEuphorieAccountPlugin),
                                 visibility=None)
 
-
     # Instruct the email module to use quoted printable for UT8
     import email.Charset
-    email.Charset.add_charset("utf-8", email.Charset.QP, email.Charset.QP, "utf-8")
+    email.Charset.add_charset('utf-8', email.Charset.QP, email.Charset.QP,
+            'utf-8')
 
+    # Monkeypatch the publisher to disable its WebDAV logic so we can use
+    # all request methods for our REST API.
+    import ZPublisher.HTTPRequest
+    ZPublisher.HTTPRequest.HTTPRequest.maybe_webdav_client = 0
